@@ -27,7 +27,7 @@
 
 class AsciiValidator: public TQValidator
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     AsciiValidator( TQObject * parent, const char *name = 0 );
