@@ -966,7 +966,7 @@ TQPixmap qChoosePixmap( TQWidget *parent, FormWindow *fw, const TQPixmap &old, T
 	    TQPixmap pix( fd.selectedFile() );
 	    if ( fn )
 		*fn = fd.selectedFile();
-	    MetaDataBase::setPixmapArgument( TQT_TQOBJECT(fw), pix.serialNumber(), fd.selectedFile() );
+	    MetaDataBase::setPixmapArgument( fw, pix.serialNumber(), fd.selectedFile() );
 	    return pix;
 	}
     }
@@ -985,13 +985,13 @@ TQPixmap qChoosePixmap( TQWidget *parent, FormWindow *fw, const TQPixmap &old, T
 #endif
     else {
 	PixmapFunction dia( parent, 0, true );
-	TQObject::connect( dia.helpButton, TQT_SIGNAL( clicked() ), MainWindow::self, TQT_SLOT( showDialogHelp() ) );
+	TQObject::connect( dia.helpButton, TQ_SIGNAL( clicked() ), MainWindow::self, TQ_SLOT( showDialogHelp() ) );
 	dia.labelFunction->setText( fw->pixmapLoaderFunction() + "(" );
-	dia.editArguments->setText( MetaDataBase::pixmapArgument( TQT_TQOBJECT(fw), old.serialNumber() ) );
+	dia.editArguments->setText( MetaDataBase::pixmapArgument( fw, old.serialNumber() ) );
 	dia.editArguments->setFocus();
 	if ( dia.exec() == TQDialog::Accepted ) {
 	    TQPixmap pix( PixmapChooser::loadPixmap( "image.xpm" ) );
-	    MetaDataBase::setPixmapArgument( TQT_TQOBJECT(fw), pix.serialNumber(), dia.editArguments->text() );
+	    MetaDataBase::setPixmapArgument( fw, pix.serialNumber(), dia.editArguments->text() );
 	    return pix;
 	}
     }
@@ -1004,7 +1004,7 @@ TQPixmap qChoosePixmap( TQWidget *parent, FormWindow *fw, const TQPixmap &old, T
 }
 
 ImageIconProvider::ImageIconProvider( TQWidget *parent, const char *name )
-    : TQFileIconProvider( TQT_TQOBJECT(parent), name ), imagepm( PixmapChooser::loadPixmap( "image.xpm", PixmapChooser::Mini ) )
+    : TQFileIconProvider( parent, name ), imagepm( PixmapChooser::loadPixmap( "image.xpm", PixmapChooser::Mini ) )
 {
     fmts = TQImage::inputFormats();
 }
@@ -1016,7 +1016,7 @@ ImageIconProvider::~ImageIconProvider()
 const TQPixmap * ImageIconProvider::pixmap( const TQFileInfo &fi )
 {
     TQString ext = fi.extension().upper();
-    if ( fmts.contains( ext ) ) {
+    if ( fmts.contains( ext.utf8() ) ) {
 	return &imagepm;
     } else {
 	return TQFileIconProvider::pixmap( fi );
