@@ -28,7 +28,7 @@
 
 class PreviewWorkspace : public TQWorkspace
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     PreviewWorkspace( TQWidget* parent = 0, const char* name = 0 )
@@ -41,7 +41,7 @@ protected:
 
 class PreviewFrame : public TQVBox
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
