@@ -25,9 +25,9 @@
 
 #if KDE_IS_VERSION(3,3,90)
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 
-#define KOMMANDER_EXPORT KDE_EXPORT
+#define KOMMANDER_EXPORT TDE_EXPORT
 
 #else
 #define KOMMANDER_EXPORT
