@@ -98,10 +98,10 @@ void QuantaDebuggerGubed::startSession()
     {
       m_socket = new KNetwork::KStreamSocket(m_serverHost, m_serverPort);
 
-      connect(m_socket, TQT_SIGNAL(gotError(int)), this, TQT_SLOT(slotError(int)));
-      connect(m_socket, TQT_SIGNAL(connected(const KResolverEntry &)), this, TQT_SLOT(slotConnected(const KResolverEntry &)));
-      connect(m_socket, TQT_SIGNAL(closed()), this, TQT_SLOT(slotConnectionClosed()));
-      connect(m_socket, TQT_SIGNAL(readyRead()), this, TQT_SLOT(slotReadyRead()));
+      connect(m_socket, TQ_SIGNAL(gotError(int)), this, TQ_SLOT(slotError(int)));
+      connect(m_socket, TQ_SIGNAL(connected(const KResolverEntry &)), this, TQ_SLOT(slotConnected(const KResolverEntry &)));
+      connect(m_socket, TQ_SIGNAL(closed()), this, TQ_SLOT(slotConnectionClosed()));
+      connect(m_socket, TQ_SIGNAL(readyRead()), this, TQ_SLOT(slotReadyRead()));
 
       m_socket->connect();
       debuggerInterface()->enableAction("debug_connect", true);
@@ -119,7 +119,7 @@ void QuantaDebuggerGubed::startSession()
       m_server = new KNetwork::TDEServerSocket(m_listenPort);
 
       m_server->setAddressReuseable(true);
-      connect(m_server, TQT_SIGNAL(readyAccept()), this, TQT_SLOT(slotReadyAccept()));
+      connect(m_server, TQ_SIGNAL(readyAccept()), this, TQ_SLOT(slotReadyAccept()));
 
       if(m_server->listen())
       {
@@ -280,7 +280,7 @@ void QuantaDebuggerGubed::slotReadyAccept()
   {
 
     // Perhaps this shouldnt be disconnected - instead check if connections are available at disconnect?
-    disconnect(m_server, TQT_SIGNAL(readyAccept()), this, TQT_SLOT(slotReadyAccept()));
+    disconnect(m_server, TQ_SIGNAL(readyAccept()), this, TQ_SLOT(slotReadyAccept()));
 
     m_socket = (KNetwork::KStreamSocket *)m_server->accept(); // TDESocketServer returns a KStreamSocket (!)
     if(m_socket)
@@ -288,10 +288,10 @@ void QuantaDebuggerGubed::slotReadyAccept()
       kdDebug(24002) << k_funcinfo << ", ready" << endl;
       m_socket->enableRead(true);
 
-      connect(m_socket, TQT_SIGNAL(gotError(int)), this, TQT_SLOT(slotError(int)));
-      connect(m_socket, TQT_SIGNAL(connected(const KResolverEntry &)), this, TQT_SLOT(slotConnected(const KResolverEntry &)));
-      connect(m_socket, TQT_SIGNAL(closed()), this, TQT_SLOT(slotConnectionClosed()));
-      connect(m_socket, TQT_SIGNAL(readyRead()), this, TQT_SLOT(slotReadyRead()));
+      connect(m_socket, TQ_SIGNAL(gotError(int)), this, TQ_SLOT(slotError(int)));
+      connect(m_socket, TQ_SIGNAL(connected(const KResolverEntry &)), this, TQ_SLOT(slotConnected(const KResolverEntry &)));
+      connect(m_socket, TQ_SIGNAL(closed()), this, TQ_SLOT(slotConnectionClosed()));
+      connect(m_socket, TQ_SIGNAL(readyRead()), this, TQ_SLOT(slotReadyRead()));
       connected();
 
       emit updateStatus(DebuggerUI::Connected);
@@ -339,7 +339,7 @@ void QuantaDebuggerGubed::slotConnectionClosed()
   }
 
   if(m_server)
-    connect(m_server, TQT_SIGNAL(readyAccept()), this, TQT_SLOT(slotReadyAccept()));
+    connect(m_server, TQ_SIGNAL(readyAccept()), this, TQ_SLOT(slotReadyAccept()));
 
   // Disable all session related actions and enable connection action
   debuggerInterface()->enableAction("*", false);
