@@ -52,21 +52,21 @@ TableEditor::TableEditor(TQWidget* parent, const char* name)
   : TableEditorS(parent, name)
 {
   m_popup = new TDEPopupMenu();
-  m_cellEditId = m_popup->insertItem(i18n("&Edit Cell Properties"), this ,TQT_SLOT(slotEditCell()));
-  m_rowEditId = m_popup->insertItem(i18n("Edit &Row Properties"), this ,TQT_SLOT(slotEditRow()));
-  //  m_colEditId = m_popup->insertItem(i18n("Edit &Column Properties"), this ,TQT_SLOT(slotEditCol()));
+  m_cellEditId = m_popup->insertItem(i18n("&Edit Cell Properties"), this ,TQ_SLOT(slotEditCell()));
+  m_rowEditId = m_popup->insertItem(i18n("Edit &Row Properties"), this ,TQ_SLOT(slotEditRow()));
+  //  m_colEditId = m_popup->insertItem(i18n("Edit &Column Properties"), this ,TQ_SLOT(slotEditCol()));
   m_mergeSeparatorId = m_popup->insertSeparator();
-  m_mergeCellsId = m_popup->insertItem(i18n("Merge Cells"), this, TQT_SLOT(slotMergeCells()));
-  m_unmergeCellsId = m_popup->insertItem(i18n("Break Merging"), this, TQT_SLOT(slotUnmergeCells()));
+  m_mergeCellsId = m_popup->insertItem(i18n("Merge Cells"), this, TQ_SLOT(slotMergeCells()));
+  m_unmergeCellsId = m_popup->insertItem(i18n("Break Merging"), this, TQ_SLOT(slotUnmergeCells()));
 
   m_popup->insertSeparator();
-  m_popup->insertItem(i18n("&Insert Row"), this, TQT_SLOT(slotInsertRow()));
-  m_popup->insertItem(i18n("Insert Co&lumn"), this, TQT_SLOT(slotInsertCol()));
-  m_popup->insertItem(i18n("Remove Row"), this, TQT_SLOT(slotRemoveRow()));
-  m_popup->insertItem(i18n("Remove Column"), this, TQT_SLOT(slotRemoveCol()));
+  m_popup->insertItem(i18n("&Insert Row"), this, TQ_SLOT(slotInsertRow()));
+  m_popup->insertItem(i18n("Insert Co&lumn"), this, TQ_SLOT(slotInsertCol()));
+  m_popup->insertItem(i18n("Remove Row"), this, TQ_SLOT(slotRemoveRow()));
+  m_popup->insertItem(i18n("Remove Column"), this, TQ_SLOT(slotRemoveCol()));
   m_popup->insertSeparator();
-  m_popup->insertItem(i18n("Edit &Table Properties"), this, TQT_SLOT(slotEditTable()));
-  m_editChildId = m_popup->insertItem(i18n("Edit Child Table"), this, TQT_SLOT(slotEditChildTable()));
+  m_popup->insertItem(i18n("Edit &Table Properties"), this, TQ_SLOT(slotEditTable()));
+  m_editChildId = m_popup->insertItem(i18n("Edit Child Table"), this, TQ_SLOT(slotEditChildTable()));
 
   buttonOk->setIconSet(SmallIconSet("button_ok"));
   buttonCancel->setIconSet(SmallIconSet("button_cancel"));
@@ -90,27 +90,27 @@ TableEditor::TableEditor(TQWidget* parent, const char* name)
   m_createNodes = true;
   newNum += 7;
 
-  connect(headerColSpinBox, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(slotAddRemoveCol(int)));
-  connect(headerRowSpinBox, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(slotAddRemoveRow(int)));
-  connect(rowSpinBox, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(slotAddRemoveRow(int)));
-  connect(colSpinBox, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(slotAddRemoveCol(int)));
-  connect(footerRowSpinBox, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(slotAddRemoveRow(int)));
-  connect(footerColSpinBox, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(slotAddRemoveCol(int)));
-  connect(tableData, TQT_SIGNAL(contextMenuRequested(int,int,const TQPoint&)),
-    TQT_SLOT(slotContextMenuRequested(int,int,const TQPoint&)));
-  connect(pushButton7, TQT_SIGNAL(clicked()), TQT_SLOT(slotEditTable()));
-  connect(pushButton7_2, TQT_SIGNAL(clicked()), TQT_SLOT(slotEditTableBody()));
-  connect(pushButton7_3, TQT_SIGNAL(clicked()), TQT_SLOT(slotEditTableHeader()));
-  connect(pushButton7_4, TQT_SIGNAL(clicked()), TQT_SLOT(slotEditTableFooter()));
-  connect(headerTableData, TQT_SIGNAL(contextMenuRequested(int,int,const TQPoint&)),
-    TQT_SLOT(slotContextMenuRequested(int,int,const TQPoint&)));
-  connect(footerTableData, TQT_SIGNAL(contextMenuRequested(int,int,const TQPoint&)),
-    TQT_SLOT(slotContextMenuRequested(int,int,const TQPoint&)));
-  connect(tabWidget, TQT_SIGNAL(currentChanged(TQWidget*)), TQT_SLOT(slotTabChanged(TQWidget*)));
-  connect(buttonHelp, TQT_SIGNAL(clicked()), TQT_SLOT(slotHelpInvoked()));
-  connect(tableData, TQT_SIGNAL(valueChanged(int,int)), TQT_SLOT(slotEditCellText(int,int)));
-  connect(headerTableData, TQT_SIGNAL(valueChanged(int,int)), TQT_SLOT(slotEditCellText(int,int)));
-  connect(footerTableData, TQT_SIGNAL(valueChanged(int,int)), TQT_SLOT(slotEditCellText(int,int)));
+  connect(headerColSpinBox, TQ_SIGNAL(valueChanged(int)), TQ_SLOT(slotAddRemoveCol(int)));
+  connect(headerRowSpinBox, TQ_SIGNAL(valueChanged(int)), TQ_SLOT(slotAddRemoveRow(int)));
+  connect(rowSpinBox, TQ_SIGNAL(valueChanged(int)), TQ_SLOT(slotAddRemoveRow(int)));
+  connect(colSpinBox, TQ_SIGNAL(valueChanged(int)), TQ_SLOT(slotAddRemoveCol(int)));
+  connect(footerRowSpinBox, TQ_SIGNAL(valueChanged(int)), TQ_SLOT(slotAddRemoveRow(int)));
+  connect(footerColSpinBox, TQ_SIGNAL(valueChanged(int)), TQ_SLOT(slotAddRemoveCol(int)));
+  connect(tableData, TQ_SIGNAL(contextMenuRequested(int,int,const TQPoint&)),
+    TQ_SLOT(slotContextMenuRequested(int,int,const TQPoint&)));
+  connect(pushButton7, TQ_SIGNAL(clicked()), TQ_SLOT(slotEditTable()));
+  connect(pushButton7_2, TQ_SIGNAL(clicked()), TQ_SLOT(slotEditTableBody()));
+  connect(pushButton7_3, TQ_SIGNAL(clicked()), TQ_SLOT(slotEditTableHeader()));
+  connect(pushButton7_4, TQ_SIGNAL(clicked()), TQ_SLOT(slotEditTableFooter()));
+  connect(headerTableData, TQ_SIGNAL(contextMenuRequested(int,int,const TQPoint&)),
+    TQ_SLOT(slotContextMenuRequested(int,int,const TQPoint&)));
+  connect(footerTableData, TQ_SIGNAL(contextMenuRequested(int,int,const TQPoint&)),
+    TQ_SLOT(slotContextMenuRequested(int,int,const TQPoint&)));
+  connect(tabWidget, TQ_SIGNAL(currentChanged(TQWidget*)), TQ_SLOT(slotTabChanged(TQWidget*)));
+  connect(buttonHelp, TQ_SIGNAL(clicked()), TQ_SLOT(slotHelpInvoked()));
+  connect(tableData, TQ_SIGNAL(valueChanged(int,int)), TQ_SLOT(slotEditCellText(int,int)));
+  connect(headerTableData, TQ_SIGNAL(valueChanged(int,int)), TQ_SLOT(slotEditCellText(int,int)));
+  connect(footerTableData, TQ_SIGNAL(valueChanged(int,int)), TQ_SLOT(slotEditCellText(int,int)));
 }
 
 TableEditor::~TableEditor()
