@@ -23,7 +23,7 @@
 
 class FileMasks : public FileMasksS
 {
-   Q_OBJECT
+   TQ_OBJECT
   
 public:
   FileMasks(TQWidget *parent=0, const char *name=0);
