@@ -73,7 +73,7 @@ void QuantaPlugin::setPluginName(const TQString &a_name)
   m_name = a_name;
   if (!m_action)
   {
-    m_action = new TDEToggleAction(i18n(a_name.utf8()), 0, this, TQT_SLOT(toggle()), quantaApp->actionCollection(), a_name.ascii());
+    m_action = new TDEToggleAction(i18n(a_name.utf8()), 0, this, TQ_SLOT(toggle()), quantaApp->actionCollection(), a_name.ascii());
   }
   m_action->setText(a_name);
 }
@@ -114,9 +114,9 @@ bool QuantaPlugin::load()
   TQString ow = outputWindow();
   m_targetWidget =  new TQWidget(quantaApp);
   if (m_readOnlyPart)
-      m_part = KParts::ComponentFactory::createPartInstanceFromLibrary<KParts::ReadOnlyPart>(partInfo.baseName().latin1(), m_targetWidget, 0, TQT_TQOBJECT(m_targetWidget), 0 );
+      m_part = KParts::ComponentFactory::createPartInstanceFromLibrary<KParts::ReadOnlyPart>(partInfo.baseName().latin1(), m_targetWidget, 0, m_targetWidget, 0 );
   else
-      m_part = KParts::ComponentFactory::createPartInstanceFromLibrary<KParts::ReadWritePart>(partInfo.baseName().latin1(), m_targetWidget, 0, TQT_TQOBJECT(m_targetWidget), 0 );
+      m_part = KParts::ComponentFactory::createPartInstanceFromLibrary<KParts::ReadWritePart>(partInfo.baseName().latin1(), m_targetWidget, 0, m_targetWidget, 0 );
   if(!m_part)
   {
     KMessageBox::error(quantaApp, i18n("<qt>The <b>%1</b> plugin could not be loaded.<br>Possible reasons are:<br>    - <b>%2</b> is not installed;<br>    - the file <i>%3</i> is not installed or it is not reachable.").arg(m_name).arg(m_name).arg(m_fileName));
@@ -184,8 +184,8 @@ bool QuantaPlugin::run()
     }
     addWidget();
     setRunning(true);
-    connect( m_part, TQT_SIGNAL(setStatusBarText(const TQString &)),
-           quantaApp, TQT_SLOT(slotStatusMsg( const TQString & )));
+    connect( m_part, TQ_SIGNAL(setStatusBarText(const TQString &)),
+           quantaApp, TQ_SLOT(slotStatusMsg( const TQString & )));
 
 
     emit pluginStarted();
@@ -287,8 +287,8 @@ bool QuantaPlugin::unload(bool remove)
   if(!isLoaded())
     return false;
 
-  disconnect( m_part, TQT_SIGNAL(setStatusBarText(const TQString &)),
-           quantaApp, TQT_SLOT(slotStatusMsg( const TQString & )));
+  disconnect( m_part, TQ_SIGNAL(setStatusBarText(const TQString &)),
+           quantaApp, TQ_SLOT(slotStatusMsg( const TQString & )));
 
   delete (KParts::ReadOnlyPart*) m_part;
   m_part = 0;
