@@ -20,8 +20,8 @@
 NewTemplateDirDlg::NewTemplateDirDlg(TQWidget *parent, const char *name ) : TemplateDirForm(parent,name)
 {
   setCaption(name);
-  connect( buttonOk, TQT_SIGNAL(clicked()), TQT_SLOT(accept()) );
-  connect( buttonCancel, TQT_SIGNAL(clicked()), TQT_SLOT(reject()) );
+  connect( buttonOk, TQ_SIGNAL(clicked()), TQ_SLOT(accept()) );
+  connect( buttonCancel, TQ_SIGNAL(clicked()), TQ_SLOT(reject()) );
 }
 
 NewTemplateDirDlg::~NewTemplateDirDlg()
